Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrExists = errors.New("already exists") ErrUnsupported = errors.New("not supported by this forge") )
Functions ¶
This section is empty.
Types ¶
type Forge ¶
type Forge interface {
Create(ctx context.Context, user string, m Meta) error
Update(ctx context.Context, user string, m Meta) error
Archive(ctx context.Context, user, name string, flag bool) error
Delete(ctx context.Context, user, name string) error
List(ctx context.Context, user string) ([]string, error)
Sync(ctx context.Context, user string, m Meta) error
}
forge abstracts forge CRUD operations create returns ErrExists if the repo already exists archive may return ErrUnsupported on forges without archive API list returns all repos owned by the authenticated user sync is create-or-update with archive handling
Click to show internal directories.
Click to hide internal directories.